@@ -249,8 +249,9 @@ class Farm(Resource):
         return Server(self, server_def)
 
     def servers(self):
-        # We are limited to 100 servers max on an IPLB
-        return [self.server(server_def) for server_def in self.farm_def.get('servers', [])][:100]
+        # We are limited to 100 servers max on an IPLB farm. As new servers are added before the existing ones are
+        # removed, proceed with only 50 so that even if they are all new, they can still be created.
+        return [self.server(server_def) for server_def in self.farm_def.get('servers', [])][:50]
 
     def remove_orphan_server(self, servers=None):
         servers = servers or self.servers()
@@ -334,7 +335,8 @@ class IPLB(Resource):
     def task_in_progress(self):
         tasks = self.subresource('task', no_cache=True)
         return len(tuple(
-            filter(lambda task: task['status'] != 'done', tasks)
+            # Certificate ordering can be blocked for a few days, ignore these tasks
+            filter(lambda task: task['status'] != 'done' and not task['action'].startswith('order'), tasks)
         )) > 0
 
     def refresh(self):
