@@ -90,8 +90,8 @@ class TestIplb(PrepareMockedIPLB, unittest.TestCase):
     def test_task_in_progress_when_task_not_done(self):
         self.mock_get({
             '/ipLoadbalancing/iplb_id/task': [1, 2],
-            '/ipLoadbalancing/iplb_id/task/1': {'status': 'doing'},
-            '/ipLoadbalancing/iplb_id/task/2': {'status': 'done'},
+            '/ipLoadbalancing/iplb_id/task/1': {'status': 'doing', 'action': 'refreshIPLB'},
+            '/ipLoadbalancing/iplb_id/task/2': {'status': 'done', 'action': 'refreshIPLB'},
         })
 
         self.assertTrue(self.iplb.task_in_progress())
@@ -99,25 +99,27 @@ class TestIplb(PrepareMockedIPLB, unittest.TestCase):
     def test_task_in_progress_when_all_task_done(self):
         self.mock_get({
             '/ipLoadbalancing/iplb_id/task': [1, 2],
-            '/ipLoadbalancing/iplb_id/task/1': {'status': 'done'},
-            '/ipLoadbalancing/iplb_id/task/2': {'status': 'done'},
+            '/ipLoadbalancing/iplb_id/task/1': {'status': 'done', 'action': 'refreshIPLB'},
+            '/ipLoadbalancing/iplb_id/task/2': {'status': 'done', 'action': 'refreshIPLB'},
         })
 
         self.assertFalse(self.iplb.task_in_progress())
 
     def test_task_in_progress_when_task_move_from_not_done_to_done(self):
         self.mock_get({
-            '/ipLoadbalancing/iplb_id/task': [1, 2],
-            '/ipLoadbalancing/iplb_id/task/1': {'status': 'doing'},
-            '/ipLoadbalancing/iplb_id/task/2': {'status': 'done'},
+            '/ipLoadbalancing/iplb_id/task': [1, 2, 3],
+            '/ipLoadbalancing/iplb_id/task/1': {'status': 'doing', 'action': 'refreshIPLB'},
+            '/ipLoadbalancing/iplb_id/task/2': {'status': 'done', 'action': 'refreshIPLB'},
+            '/ipLoadbalancing/iplb_id/task/3': {'status': 'todo', 'action': 'orderFreeCertificate'},
         })
 
         self.assertTrue(self.iplb.task_in_progress())
 
         self.mock_get({
-            '/ipLoadbalancing/iplb_id/task': [1, 2],
-            '/ipLoadbalancing/iplb_id/task/1': {'status': 'done'},
-            '/ipLoadbalancing/iplb_id/task/2': {'status': 'done'},
+            '/ipLoadbalancing/iplb_id/task': [1, 2, 3],
+            '/ipLoadbalancing/iplb_id/task/1': {'status': 'done', 'action': 'refreshIPLB'},
+            '/ipLoadbalancing/iplb_id/task/2': {'status': 'done', 'action': 'refreshIPLB'},
+            '/ipLoadbalancing/iplb_id/task/3': {'status': 'todo', 'action': 'orderFreeCertificate'},
         })
 
         self.assertFalse(self.iplb.task_in_progress())
@@ -672,7 +674,7 @@ class TestFarm(PrepareMockedIPLB, unittest.TestCase):
                                         'zone': 'gra',
                                         'servers': [{'address': '8.8.8.8'}]}).apply())
 
-    def test_apply_with_more_than_100_servers(self):
+    def test_apply_with_more_than_50_servers(self):
         self.mock_get({
             '/ipLoadbalancing/iplb_id/tcp/farm/42/server': [],
             '/ipLoadbalancing/iplb_id/tcp/farm/42': {'farmId': 42, 'displayName': 'name', 'zone': 'gra'},
@@ -686,8 +688,8 @@ class TestFarm(PrepareMockedIPLB, unittest.TestCase):
                                         'servers': [{'address': '8.8.8.{}'.format(i)} for i in range(120)]}).apply())
 
         self.mocked_client_instance.post.assert_called_with('/ipLoadbalancing/iplb_id/tcp/farm/42/server',
-                                                            address='8.8.8.99')
-        self.assertEqual(self.mocked_client_instance.post.call_count, 100)
+                                                            address='8.8.8.49')
+        self.assertEqual(self.mocked_client_instance.post.call_count, 50)
 
     def test_apply_with_servers_to_update(self):
         self.mock_get({
